<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>ShowDesktop</name>
    <message>
        <location filename="../../../showdesktop.cpp" line="44"/>
        <source>Show desktop</source>
        <translation>デスクトップの表示</translation>
    </message>
    <message>
        <location filename="../../../showdesktop.cpp" line="66"/>
        <source>Show Desktop: Global shortcut &apos;%1&apos; cannot be registered</source>
        <translation>デスクトップの表示: グローバルなショートカット &apos;%1&apos; は登録できません</translation>
    </message>
    <message>
        <location filename="../../../showdesktop.cpp" line="51"/>
        <source>Show Desktop</source>
        <translation>デスクトップを表示</translation>
    </message>
</context>
</TS>
